@@ -31,10 +31,11 @@
 #include <dballe/core/record.h>
 #include <dballe/core/defs.h>
 
-#include <limits.h>
 #include <cstring>
 #include <cstdlib>
 #include <cstdio>
+#include <limits.h>
+#include <unistd.h>
 
 #include <sql.h>
 
@@ -533,8 +534,15 @@ void DB::init_after_connect()
     /* Set manual commit */
     if (conn->server_type == db::SQLITE)
     {
-        run_sql("PRAGMA journal_mode = MEMORY");
-        run_sql("PRAGMA legacy_file_format = 0");
+        if (getenv("DBA_INSECURE_SQLITE") != NULL)
+        {
+            run_sql("PRAGMA synchronous = OFF");
+            run_sql("PRAGMA journal_mode = OFF");
+            run_sql("PRAGMA legacy_file_format = 0");
+        } else {
+            run_sql("PRAGMA journal_mode = MEMORY");
+            run_sql("PRAGMA legacy_file_format = 0");
+        }
     } else
         conn->set_autocommit(false);
 #endif
