@@ -1,7 +1,5 @@
 /*
- * DB-ALLe - Archive for punctual meteorological data
- *
- * Copyright (C) 2005,2006  ARPA-SIM <urpsim@smr.arpa.emr.it>
+ * Copyright (C) 2005--2010  ARPA-SIM <urpsim@smr.arpa.emr.it>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,23 +21,21 @@
 #include <dballe/db/db.h>
 #include <sqltypes.h>
 
-namespace tut_dballe {
-using namespace std;
-using namespace tut;
+namespace dballe {
+namespace tests {
 
 struct db_test
 {
-    // DB handle
-    dba_db db;
+	// DB handle
+	DB* db;
 
 	bool has_db() const { return db != NULL; }
 	void use_db();
 
-    db_test();
+	db_test();
 	~db_test();
 };
 
-
 static inline SQL_TIMESTAMP_STRUCT mkts(int year, int month, int day, int hour, int minute, int second)
 {
 	SQL_TIMESTAMP_STRUCT res;
@@ -53,12 +49,17 @@ static inline SQL_TIMESTAMP_STRUCT mkts(int year, int month, int day, int hour,
 	return res;
 }
 
+} // namespace tests
+} // namespace dballe
+
+namespace std {
+
 static inline bool operator!=(const SQL_TIMESTAMP_STRUCT& a, const SQL_TIMESTAMP_STRUCT& b)
 {
 	return a.year != b.year || a.month != b.month || a.day != b.day || a.hour != b.hour || a.minute != b.minute || a.second != b.second || a.fraction != b.fraction;
 }
 
-static inline ostream& operator<<(ostream& o, const SQL_TIMESTAMP_STRUCT& t)
+static inline std::ostream& operator<<(std::ostream& o, const SQL_TIMESTAMP_STRUCT& t)
 {
 	char buf[20];
 	snprintf(buf, 20, "%04d-%02d-%02d %02d:%02d:%02d.%d", t.year, t.month, t.day, t.hour, t.minute, t.second, t.fraction);
@@ -66,7 +67,6 @@ static inline ostream& operator<<(ostream& o, const SQL_TIMESTAMP_STRUCT& t)
 	return o;
 }
 
-
 }
 
 // vim:set ts=4 sw=4:
