@@ -4,6 +4,8 @@
 ! * Test suite for DBALLE Fortran bindings
 ! *****************************************
 
+      use dbtest
+
       include "dballef.h"
 
       integer dbahandle, handle, ival
@@ -16,8 +18,7 @@
 !      call fdba_error_set_callback(0, testcb, 2, i)
 
 !     Database login
-      call idba_presentati(dbahandle, "test", "enrico", "")
-      call ensure_no_error("presentati")
+      call dbinit(dbahandle)
 
 !     Open a session
       call idba_preparati(dbahandle, handle, "write", "write", "write")
@@ -79,6 +80,12 @@
       call idba_setd(handle, "B12001", DBA_MVD)
       call ensure_no_error("unset var double")
 
+      call idba_fatto(handle)
+      call ensure_no_error("fatto")
+
+      call idba_arrivederci(dbahandle)
+      call ensure_no_error("arrivederci")
+  
 !     If we made it so far, exit with no error
       print*,"check_missing: all tests succeed."
 
