@@ -1,6 +1,13 @@
 import wx
+import dballe
 from provami.QueryChoice import QueryChoice
 
+def intormiss(x):
+    if x == dballe.MISSING_INT:
+        return "-"
+    else:
+        return "%d" % x
+
 class TimeRangeChoice(QueryChoice):
     def __init__(self, parent, model):
         QueryChoice.__init__(self, parent, model, "trange", "tranges")
@@ -13,14 +20,14 @@ class TimeRangeChoice(QueryChoice):
         res = []
         res.append(("All time ranges", None))
         for tr in self.model.timeranges():
-            res.append(("%d,%d,%d" % tr, tr))
+            res.append((",".join([intormiss(x) for x in tr]), tr))
         return res
 
     def selected(self, event):
         if self.updating: return
         sel = self.GetSelection()
         tr = self.GetClientData(sel)
-        if tr == None:
+        if tr is None:
             self.model.setTimeRangeFilter(None)
         else:
             self.model.setTimeRangeFilter(tr)
