@@ -57,6 +57,7 @@ static int op_dump_csv = 0;
 static int op_dump_dds = 0;
 static int op_dump_structured = 0;
 static int op_precise_import = 0;
+static int op_recompute_categories = 0;
 static const char* op_output_type = "bufr";
 static const char* op_output_template = "";
 static const char* op_report = "";
@@ -569,9 +570,11 @@ int do_scan(poptContext optCon)
     /* Throw away the command name */
     poptGetArg(optCon);
 
-    reader.filter.matcher_from_args(optCon);
+    Record query;
+    if (dba_cmdline_get_query(optCon, query) > 0)
+        reader.filter.matcher_from_record(query);
     Summarise s;
-    reader.read(optCon, s);
+    reader.read(get_filenames(optCon), s);
     return 0;
 }
 
@@ -580,9 +583,12 @@ int do_head(poptContext optCon)
     /* Throw away the command name */
     poptGetArg(optCon);
 
-    reader.filter.matcher_from_args(optCon);
+    Record query;
+    if (dba_cmdline_get_query(optCon, query) > 0)
+        reader.filter.matcher_from_record(query);
+
     Head head;
-    reader.read(optCon, head);
+    reader.read(get_filenames(optCon), head);
     return 0;
 }
 
@@ -610,8 +616,12 @@ int do_dump(poptContext optCon)
     /* Throw away the command name */
     poptGetArg(optCon);
     if (op_precise_import) reader.import_opts.simplified = false;
-    reader.filter.matcher_from_args(optCon);
-    reader.read(optCon, *action);
+
+    Record query;
+    if (dba_cmdline_get_query(optCon, query) > 0)
+        reader.filter.matcher_from_record(query);
+
+    reader.read(get_filenames(optCon), *action);
     return 0;
 }
 
@@ -620,10 +630,13 @@ int do_cat(poptContext optCon)
     /* Throw away the command name */
     poptGetArg(optCon);
 
-    reader.filter.matcher_from_args(optCon);
+    Record query;
+    if (dba_cmdline_get_query(optCon, query) > 0)
+        reader.filter.matcher_from_record(query);
+
     /*DBA_RUN_OR_RETURN(aof_file_write_header(file, 0, 0)); */
     WriteRaw wraw;
-    reader.read(optCon, wraw);
+    reader.read(get_filenames(optCon), wraw);
     return 0;
 }
 
@@ -762,10 +775,13 @@ int do_convert(poptContext optCon)
 		return 0;
 	}
 
-    reader.filter.matcher_from_args(optCon);
+    Record query;
+    if (dba_cmdline_get_query(optCon, query) > 0)
+        reader.filter.matcher_from_record(query);
+
     if (op_precise_import) reader.import_opts.simplified = false;
 
-	Encoding outtype = dba_cmdline_stringToMsgType(op_output_type, optCon);
+	Encoding outtype = dba_cmdline_stringToMsgType(op_output_type);
 
 	if (op_report[0] != 0)
 		conv.dest_rep_memo = op_report;
@@ -778,10 +794,12 @@ int do_convert(poptContext optCon)
 		opts.template_name = op_output_template;
 	}
 
+    conv.recompute_categories = op_recompute_categories != 0;
+
     conv.file = File::create(outtype, "(stdout)", "w").release();
     conv.exporter = msg::Exporter::create(outtype, opts).release();
 
-    reader.read(optCon, conv);
+    reader.read(get_filenames(optCon), conv);
 
     return 0;
 }
@@ -800,8 +818,8 @@ int do_compare(poptContext optCon)
 	if (file2_name == NULL)
 		file2_name = "(stdin)";
 
-	Encoding in_type = dba_cmdline_stringToMsgType(reader.input_type, optCon);
-	Encoding out_type = dba_cmdline_stringToMsgType(op_output_type, optCon);
+	Encoding in_type = dba_cmdline_stringToMsgType(reader.input_type);
+	Encoding out_type = dba_cmdline_stringToMsgType(op_output_type);
 	File* file1 = File::create(in_type, file1_name, "r").release();
 	File* file2 = File::create(out_type, file2_name, "r").release();
 	std::auto_ptr<msg::Importer> importer = msg::Importer::create(in_type);
@@ -1122,7 +1140,7 @@ struct poptOption dbamsg_convert_options[] = {
 	{ "help", '?', 0, 0, 1, "print an help message", 0 },
 	{ "verbose", 0, POPT_ARG_NONE, &op_verbose, 0, "verbose output", 0 },
 	{ "type", 't', POPT_ARG_STRING, &reader.input_type, 0,
-		"format of the input data ('bufr', 'crex', 'aof')", "type" },
+		"format of the input data ('bufr', 'crex', 'aof', 'csv')", "type" },
 	{ "dest", 'd', POPT_ARG_STRING, &op_output_type, 0,
 		"format of the data in output ('bufr', 'crex', 'aof')", "type" },
 	{ "template", 0, POPT_ARG_STRING, &op_output_template, 0,
@@ -1131,6 +1149,8 @@ struct poptOption dbamsg_convert_options[] = {
 		"force output data to be of this type of report", "rep_memo" },
 	{ "precise", 0, 0, &op_precise_import, 0,
 		"import messages using precise contexts instead of standard ones", 0 },
+    { "recompute-categories", 0, 0, &op_recompute_categories, 0,
+        "recompute data categories and subcategories according to message contents", 0 },
 	{ NULL, 0, POPT_ARG_INCLUDE_TABLE, &grepTable, 0,
 		"Options used to filter messages", 0 },
 	POPT_TABLEEND
@@ -1148,20 +1168,6 @@ struct poptOption dbamsg_compare_options[] = {
 	POPT_TABLEEND
 };
 
-struct poptOption dbamsg_filter_options[] = {
-	{ "help", '?', 0, 0, 1, "print an help message", 0 },
-	{ "verbose", 0, POPT_ARG_NONE, &op_verbose, 0, "verbose output" },
-	{ "type", 't', POPT_ARG_STRING, &reader.input_type, 0,
-		"format of the input data ('bufr', 'crex', 'aof')", "type" },
-	{ "dest", 'd', POPT_ARG_STRING, &op_output_type, 0,
-		"format of the data in output ('bufr', 'crex', 'aof')", "type" },
-	{ "precise", 0, 0, &op_precise_import, 0,
-		"import messages using precise contexts instead of standard ones", 0 },
-	{ NULL, 0, POPT_ARG_INCLUDE_TABLE, &grepTable, 0,
-		"Options used to filter messages", 0 },
-	POPT_TABLEEND
-};
-
 struct poptOption dbamsg_fixaof_options[] = {
 	{ "help", '?', 0, 0, 1, "print an help message", 0 },
 	{ "verbose", 0, POPT_ARG_NONE, &op_verbose, 0, "verbose output", 0 },
